%MIREADVOLUMES  Read volumes from a MINC file into multidimensional matrix
%
%  matrix = mireadvolumes ('minc_file', rows, cols, slices, frames)
%
%  Any of the volume indices (rows, cols, slices, frames) can be
%  either a single value or a vector of values.  If a vector, the
%  values do not need to be contiguous.  Note that the indices are
%  **zero-based**, and not one-based as in matlab (the output,
%  being a matlab matrix, is of course one-based).  The input
%  indices *must* be sorted in ascending order (calling through
%  getvolumes ensures this).   
%
%  The output matrix indices will represent the fastest to slowest
%  varying dimensions of the binary array in the minc file.  Due to
%  the way that image data is exported from virtually all imaging
%  systems, the output indexing typically corresponds to the image
%  dimensions of
%
%    column, row, slice, frame
%
%  Exceptions might arise due to new scanner platforms or conversion
%  software however, so you might want to test this in your own env.
%  This software has been tested primarily with MINC files from
%  Siemens Vision/Sonata/Allegra systems under Numaris 3.x generated
%  using various versions of `dicomserver'.  MINC files from GE LX
%  systems converted using `ge5_to_minc' should also be ok, as well
%  as files from Philips systems converted using `gcomserver' or
%  `dicomserver'.  
%
%  On Siemens scanners under Numaris 3.5, the dimensions are arranged
%  as follows for transverse acquisitions (for the usual scenario
%  of a subject lying head first, face up in the imager):
%
%    matrix dim 1 (image column):  LEFT->RIGHT
%    matrix dim 2 (image row):     BACK->FRONT
%    matrix dim 3 (image slice):   TOP->BOTTOM
%    matrix dim 4 (image frame):   EARLY->LATE (thankfully)
%
%  For coronal acquisitions, the dimension ordering is still
%  col,row,slice,frame but the LEFT/BACK/TOP correspondences will
%  change.
%
%  NOTES:
%
%  There is no restriction against multiple slices with multiple
%  frames.  Most computers can handle this now.
%
%  Performance will be slightly slower if non-contiguous index values
%  are used.  The difference is not enough to be a big deal if you
%  want to read a volume in once and save memory by decimating it, but
%  enough to be noticible in a visualization program that repeatedly
%  reads a file for display updates.
%
%  As mentioned above, mireadvolumes expects slice and frame numbers
%  to be zero- based, whereas in MATLAB array indexing is one-based.
%  Thus, frames 0 .. 20 of the MINC file are read into columns 1 .. 21
%  of the output matrix.
%
%  The zero-based indexing used by and dimension ordering returned by
%  MIREADVOLUMES are different from the one-based row/col/slice/frame
%  indexing used externally.  MIREADVOLUMES is meant primarily for
%  internal use by matlab wrapper functions such as getvolumes and
%  GetVolRCSF.
%
%  MIREADVOLUMES assumes that the volume indices are passed in
%  ascending order.  The matlab wrapper function GETVOLUMES ensures
%  this by invoking the `sort' function on the indices.
%
%  For dynamic analysis of files with non-uniform frame spacing, you
%  may want to extract the frame timing data.  This can be done using
%  MIREADVAR (not implemented?)
%
%  In multi-slice 2D EPI, different slices are imaged at different
%  times during the inter-scan interval.  To correct for this you
%  may want to extract the array of time offsets for the different
%  slices.  This can also be done using MRREADVAR (not implemented)
%
%  For vector valued volumes such as diffusion eigenvector datasets,
%  use MIREADVECTORS (not implemented)
%
%  For 5D volumes (double time loop) such as dynamic multi-echo
%  scans use MIREADVOLUMES2 (not implemented)
%
%  MIREADVOLUMES -- written by Rick Hoge, Nov. 2001
