function miwritevolumes (filename, volumes, slices, frames)
% MIWRITEVOLUMES  write volumes to a MINC file
%
%   miwritevolumes (filename, volumes, slices, frames)
%
%  writes volumes (in the format as returned by mireadvolumes) to a MINC
%  file.  The MINC file must already exist and must have room for the 
%  data.  slices and frames only tell miwritevolumes where to put the data
%  in the MINC file, they are not used to select certain columns from volumes.
%
%  Also, the slices and frames must be valid and consistent with the MINC
%  file, which must exist and have an image variable in it.  The number
%  of volumes to write (implied by the number of elements in slices or frames)
%  must be the same as the number of columns in the matrix volumes.  Since
%  miwritevolumes only expects to be called by putvolumes, none of these
%  requirements are checked here -- all that is done by putvolumes.
%
%  Note that there is also a standalone executable miwritevolumes; this 
%  is called by miwritevolumes.m via a shell escape.  Neither of these
%  programs are meant for everyday use by the end user.

% $Id: miwritevolumes.m,v 1.2 2001/11/24 16:28:56 rhoge Exp $
% $Name:  $

if (nargin < 2) | (nargin > 4)
   help miwritevolumes
   error ('Incorrect number of arguments');
end

% If the slices vector was supplied and is non-empty, then convert it
% to a string (eg. [1 2 3] becomes '1,2,3') for passing to the executable
% miwritevolumes.  If the vector was not supplied or is empty, then 
% make the string simply a '-' to indicate no slices.  (This is only valid
% for a slice-less file.)

if (nargin < 3)
   slicelist = '-';
else
   if (~isempty (slices))
      slicelist = '';
      for i = 1:(length(slices) - 1)
         slicelist = [slicelist int2str(slices(i)-1) ','];
      end
      slicelist = [slicelist int2str(slices(length(slices))-1)];
   else
      slicelist = '-';
   end
end

% Now do the exact same thing for frames.

if (nargin < 4)
   framelist = '-';
else
   if (~isempty(frames))
      framelist = '';
      for i = 1:(length(frames) - 1)
         framelist = [framelist int2str(frames(i)-1) ','];
      end
      framelist = [framelist int2str(frames(length(frames))-1)];
   else
      framelist = '-';
   end
end

% Generate a temporary filename, create the file, and write the entire
% volumes matrix to it as doubles.


tempfile = tempfilename;

%execstr = sprintf ('miwritevolumes %s %s %s %s', ...
%   filename, slicelist, framelist, tempfile);
% disp (execstr);

outfile = fopen (tempfile, 'w');
if (outfile == -1)
   error (['Could not open temporary file ' tempfile ' for writing!']);
end

[m,n] = size (volumes);
count = fwrite (outfile, volumes, 'double');
if (count ~= m*n)
   error (['Error writing to file ' tempfile ' (probable disk full)']);
end

fclose (outfile);

% Finally, do a shell escape to miwritevolumes to write the data from the
% temporary (raw) file to the MINC file.

execstr = sprintf ('miwritevolumes %s %s %s %s', ...
   filename, slicelist, framelist, tempfile);
[result, output] = unix (execstr);

%output = mexec ('miwritevolumes', filename, slicelist, ...
%      framelist, tempfile);

%if (result ~= 0)
%   disp (['Command: ' execstr]);
%   disp ([' Output: ' output]);
%   error (['Error running miwritevolumes to write to file ' filename]);
%else
   eval (['delete ' tempfile]);
%end


